@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Data Dump Beautifier - ~/lib/Data/Pretty.pm
-## Version v0.1.1
+## Version v0.1.2
 ## Copyright(c) 2023 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2023/08/06
-## Modified 2023/08/06
+## Modified 2023/08/07
 ## All rights reserved
 ## 
 ## 
@@ -28,7 +28,7 @@ BEGIN
     @EXPORT = qw( dd ddx );
     @EXPORT_OK = qw( dump pp dumpf quote );
     our $DEBUG = 0;
-    our $VERSION = 'v0.1.1';
+    our $VERSION = 'v0.1.2';
 };
 
 use strict;
@@ -123,7 +123,10 @@ sub format_list
     my $paren = shift;
     my $comment = shift;
     my $indent_lim = $paren ? 0 : 1;
+    my $use_qw = !$paren;
+    
     if (@_ > 3) {
+        # my $use_quotes = 0;
         # can we use range operator to shorten the list?
         my $i = 0;
         while ($i < @_) {
@@ -147,18 +150,66 @@ sub format_list
             }
             if ($j - $i > 3) {
                 splice(@_, $i, $j - $i, "$_[$i] .. $_[$j-1]");
+                # splice(@_, $i, $j - $i, ( $use_quotes ? "\"$_[$i]\" .. \"$_[$j-1]\"" : "$_[$i] .. $_[$j-1]" ) );
+                $use_qw = 0;
             }
             $i++;
         }
     }
+
+    unless( !$use_qw )
+    {
+        # Quick check if we are dealing with a simple array of words/terms
+        # and thus if we can use qw( .... ) instead of ( "some", "thing", "else" )
+        my $only_numbers = 0;
+        my @repl;
+        foreach my $v ( @_ )
+        {
+            if( !defined( $v ) || 
+                ref( $v ) || 
+                # See perlop/"qw/STRING/" section
+                ( !ref( $v ) && ( $v =~ /[\,\#\$\\[:blank:]\h\v]/ || $v eq '[]' || $v eq '{}' || $v eq 'undef' ) ) )
+            {
+                $use_qw = 0;
+                @repl = ();
+                last;
+            }
+            ( my $v2 = $v ) =~ s/^\"|\"$//g;
+            push( @repl, $v2 );
+            $only_numbers++ if( $v2 =~ /^[-+]?(?:0|[1-9]\d*)(?:\.\d+)?\z/ );
+        }
+        # Don't use qw() if we are only dealing with numbers; or
+        # if there is only one value.
+        $use_qw = 0 if( $only_numbers == scalar( @_ ) || scalar( @_ ) == 1 );
+        @_ = @repl if( $use_qw );
+    }
+
     my $tmp = "@_";
+#     if ($comment || (@_ > $indent_lim && (length($tmp) > $LINEWIDTH || $tmp =~ /\n/))) {
+#         my @elem = @_;
+#         for (@elem) { s/^/$INDENT/gm; }
+#         return "\n" . ($comment ? "$INDENT# $comment\n" : "") .
+#                join(",\n", @elem, "");
     if ($comment || (@_ > $indent_lim && (length($tmp) > $LINEWIDTH || $tmp =~ /\n/))) {
-        my @elem = @_;
-        for (@elem) { s/^/$INDENT/gm; }
-        return "\n" . ($comment ? "$INDENT# $comment\n" : "") .
-               join(",\n", @elem, "");
+        my @lines = ( $comment ? "$INDENT# $comment" : () );
+        my @buf;
+        my $sep = $use_qw ? ' ' : ', ';
+        foreach my $v ( @_ )
+        {
+            if( length( $INDENT . join( $sep, @buf, $v ) ) > $LINEWIDTH )
+            {
+                push( @lines, $INDENT . join( $sep, @buf ) );
+                @buf = ( $v );
+            }
+            else
+            {
+                push( @buf, $v );
+            }
+        }
+        push( @lines, $INDENT . join( $sep, @buf ) ) if( scalar( @buf ) );
+        return ( $use_qw ? 'qw(' : '' ) . "\n" . join("\n", @lines,"") . ( $use_qw ? ')' : '' );
     } else {
-        return join(", ", @_);
+        return $use_qw ? 'qw( ' . join( ' ', @_ ) . ' )' : join(", ", @_);
     }
 }
 
@@ -307,7 +358,7 @@ sub _dump
     if ($] < 5.008 && $type eq "SCALAR") {
         $type = "REF" if $ref eq "REF";
     }
-    warn "\$$name(@$idx) $class $type $id ($ref)" if $DEBUG;
+    warn "\$$name(@$idx) ", ( $class || 'undef' ), " $type $id ($ref)" if $DEBUG;
 
     my $out;
     my $comment;
@@ -415,6 +466,7 @@ sub _dump
                 my $val = _dump($$rval, $name, [@$idx, "\$"], 0, $pclass, $pidx);
                 $out = $class ? "do{\\(my \$o = $val)}" : "\\$val";
             }
+        # NOTE; regular string
         } else {
             if (!defined $$rval) {
                 $out = "undef";
@@ -468,11 +520,38 @@ sub _dump
     elsif ($type eq "ARRAY") {
         my @vals;
         my $tied = tied_str(tied(@$rval));
-        my $i = 0;
-        for my $v (@$rval) {
-            push(@vals, _dump($v, $name, [@$idx, "[$i]"], $tied, $pclass, $pidx));
-            $i++;
-        }
+        # Quick check if we are dealing with a simple array of words/terms
+        # and thus if we can use qw( .... ) instead of ( "some", "thing", "else" )
+#         my $use_qw = 1;
+#         my $only_numbers = 0;
+#         foreach my $v ( @$rval )
+#         {
+#             if( !defined( $v ) || 
+#                 ref( $v ) || 
+#                 # See perlop/"qw/STRING/" section
+#                 ( !ref( $v ) && $v =~ /[\,\#[:blank:]\h\v]/ ) )
+#             {
+#                 $use_qw = 0;
+#                 last;
+#             }
+#             $only_numbers++ if( $v =~ /^[-+]?(?:0|[1-9]\d*)(?:\.\d+)?\z/ );
+#         }
+#         # Don't use qw() if we are only dealing with numbers
+#         $use_qw = 0 if( $only_numbers == scalar( @$rval ) );
+#         
+#         if( $use_qw )
+#         {
+#             @vals = @$rval;
+#         }
+#         else
+#         {
+            my $i = 0;
+            for my $v (@$rval) {
+                push(@vals, _dump($v, $name, [@$idx, "[$i]"], $tied, $pclass, $pidx));
+                $i++;
+            }
+#         }
+#         $out = "[" . format_list(1, $tied, $use_qw, @vals) . "]";
         $out = "[" . format_list(1, $tied, @vals) . "]";
     }
     # NOTE: hash
@@ -601,7 +680,7 @@ Data::Pretty - Data Dump Beautifier
 
 =head1 VERSION
 
-    v0.1.1
+    v0.1.2
 
 =head1 DESCRIPTION
 
@@ -669,7 +748,7 @@ You can disable this by setting C<$Data::Pretty::SHOW_UTF8> to false.
 
 =item * Quoting hash keys
 
-With C<Data::Dump>, whenever at lease 1 hash key has non alphanumeric characters, it is rightfully surrounded by double quotes, but unfortunately so are all the other hash keys who do not need surrounding double quotes.
+With C<Data::Dump>, whenever at least 1 hash key has non alphanumeric characters, it is rightfully surrounded by double quotes, but unfortunately so are all the other hash keys who do not need surrounding double quotes.
 
 Thus, for example, L<Data::Dump> would produce:
 
